@@ -1,5 +1,9 @@
 #!/usr/bin/perl
-use strict; use warnings;
+#
+# $Id: version.pl 340 2011-03-17 08:53:43Z gomor $
+#
+use strict;
+use warnings;
 
 use Net::Frame::Tools;
 
